==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/admin/help/FI/session.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - User manual                                               *
  * http://www.phpgroupware.org                                              *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: session.php,v 1.5 2003/06/16 21:42:07 kazuyan Exp $ */

	$phpgw_flags = Array(
		'currentapp'	=> 'manual',
		'admin_header'	=> True,
		'enable_utilities_class'	=> True
	);
	$phpgw_info['flags'] = $phpgw_flags;
	include('../../../header.inc.php');
	$appname = 'admin';
?>
<img src="<?php echo $phpgw->common->image($appname,'navbar.gif'); ?>" border=0>
<font face="<?php echo $phpgw_info['theme']['font']; ?>" size="2">
<p>
Tsovellus on yleensvain jjestelm pktt ktettiss
Sovelluksella hallitaan kaikkia sovelluksia, ktti ryhmija istuntojen
lokeja.
<ul>
<li><b>Istuntojen hallinta:</b>
<p><i>Ntistunnot:</i>
<br>Thetkiset istunnot, IP-osoitteet, Kirjautumisaika, aika, jonka ktt
on ollut tekemtmitn ja mahdollisuus keskeytt istunto.
<p><i>Ntkttoki:</i>
<br>Tunnus, IP-osoite, Sisnkirjautumisaika, Uloskirjautumisaika, Istunnon kesto.
</ul>
<?php $phpgw->common->phpgw_footer(); ?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/admin/help/FI/session.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - User manual                                               *
  * http://www.phpgroupware.org                                              *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: session.php,v 1.6 2004/12/26 20:31:42 kazuyan Exp $ */

	$phpgw_flags = Array(
		'currentapp'	=> 'manual',
		'admin_header'	=> True,
		'enable_utilities_class'	=> True
	);
	$phpgw_info['flags'] = $phpgw_flags;
	include('../../../header.inc.php');
	$appname = 'admin';
?>
<img src="<?php echo $phpgw->common->image($appname,'navbar.gif'); ?>" border=0>
<font face="<?php echo $phpgw_info['theme']['font']; ?>" size="2">
<p>
Tsovellus on yleensvain jjestelm pktt ktettiss
Sovelluksella hallitaan kaikkia sovelluksia, ktti ryhmija istuntojen
lokeja.
<ul>
<li><b>Istuntojen hallinta:</b>
<p><i>Ntistunnot:</i>
<br />Thetkiset istunnot, IP-osoitteet, Kirjautumisaika, aika, jonka ktt
on ollut tekemtmitn ja mahdollisuus keskeytt istunto.
<p><i>Ntkttoki:</i>
<br />Tunnus, IP-osoite, Sisnkirjautumisaika, Uloskirjautumisaika, Istunnon kesto.
</ul>
<?php $phpgw->common->phpgw_footer(); ?>
